#[repr(C)]pub struct ArrowDeviceArray {
pub device_type: i32,
pub device_id: i32,
pub array: *mut FFI_ArrowArray,
pub schema: *mut FFI_ArrowSchema,
pub release: Option<unsafe extern "C" fn(*mut ArrowDeviceArray)>,
pub private_data: *mut c_void,
}Fields
device_type: i32device_id: i32array: *mut FFI_ArrowArrayschema: *mut FFI_ArrowSchemarelease: Option<unsafe extern "C" fn(*mut ArrowDeviceArray)>private_data: *mut c_voidImplementations
Sourceimpl ArrowDeviceArray
impl ArrowDeviceArray
Sourcepub unsafe fn new(
device_type: i32,
device_id: i32,
array: *mut FFI_ArrowArray,
schema: *mut FFI_ArrowSchema,
) -> ArrowDeviceArrayOwned
pub unsafe fn new( device_type: i32, device_id: i32, array: *mut FFI_ArrowArray, schema: *mut FFI_ArrowSchema, ) -> ArrowDeviceArrayOwned
Adopt heap-owned Arrow FFI objects containing ready device allocations.
Safety
array and schema must each come from Box::into_raw, be uniquely
transferred, and describe live producer-ready device memory. Their
buffers and callbacks must support use and release from any host thread;
further producer accesses must be coordinated with the recipient.