#[repr(C, align(8))]pub struct ResidentRelationView {
pub columns: [u64; 17],
pub widths: [u32; 17],
pub arity: u32,
pub capacity: u32,
pub reserved: u32,
pub num_rows: u64,
}Expand description
Device relation view shared by every compact resident operation.
Fields
columns: [u64; 17]widths: [u32; 17]arity: u32capacity: u32reserved: u32num_rows: u64Trait Implementations
Sourceimpl Clone for ResidentRelationView
impl Clone for ResidentRelationView
Sourcefn clone(&self) -> ResidentRelationView
fn clone(&self) -> ResidentRelationView
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ResidentRelationView
Sourceimpl Debug for ResidentRelationView
impl Debug for ResidentRelationView
Sourceimpl Default for ResidentRelationView
impl Default for ResidentRelationView
Sourcefn default() -> ResidentRelationView
fn default() -> ResidentRelationView
Returns the “default value” for a type. Read more
impl DeviceRepr for ResidentRelationView
impl Eq for ResidentRelationView
Sourceimpl PartialEq for ResidentRelationView
impl PartialEq for ResidentRelationView
Sourcefn eq(&self, other: &ResidentRelationView) -> bool
fn eq(&self, other: &ResidentRelationView) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ResidentRelationView