pub struct SemanticActiveRows {
pub computed: bool,
pub rows: Vec<SemanticActiveRow>,
}Expand description
Acquired bank-local active-cache state. A computed empty result has no rows but is distinct from the initial parent which has never consumed a forward.
Fields
computed: boolrows: Vec<SemanticActiveRow>Trait Implementations
Sourceimpl Clone for SemanticActiveRows
impl Clone for SemanticActiveRows
Sourcefn clone(&self) -> SemanticActiveRows
fn clone(&self) -> SemanticActiveRows
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SemanticActiveRows
impl Debug for SemanticActiveRows
impl Eq for SemanticActiveRows
Sourceimpl PartialEq for SemanticActiveRows
impl PartialEq for SemanticActiveRows
impl StructuralPartialEq for SemanticActiveRows