pub struct SemanticPolicyFieldLayout {
pub embeddings: Range<usize>,
pub biases: Range<usize>,
pub cardinality: usize,
pub null_category: Option<usize>,
}Expand description
FP32 element ranges for one field in the native policy parameter snapshot. NULL is a category, but has no stored embedding row. The action-class field has no NULL: its category zero is the trainable no-edit action.
Fields
embeddings: Range<usize>biases: Range<usize>cardinality: usizenull_category: Option<usize>Trait Implementations
Sourceimpl Clone for SemanticPolicyFieldLayout
impl Clone for SemanticPolicyFieldLayout
Sourcefn clone(&self) -> SemanticPolicyFieldLayout
fn clone(&self) -> SemanticPolicyFieldLayout
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SemanticPolicyFieldLayout
impl Debug for SemanticPolicyFieldLayout
impl Eq for SemanticPolicyFieldLayout
impl StructuralPartialEq for SemanticPolicyFieldLayout