SemanticPublicationInputProjection

Struct SemanticPublicationInputProjection 

pub struct SemanticPublicationInputProjection {
Show 14 fields pub publication: SemanticPublishedIdentity, pub semantic_root: Identity256, pub model_generation: u64, pub model_geometry_digest: Identity256, pub model_numerical_digest: Identity256, pub neural_generation: u64, pub cache_generation: u64, pub prefix_extent: u64, pub ring_head: u64, pub prefix_identity: Identity256, pub prefix: Vec<SemanticTextSlot>, pub source: [SemanticTextSlot; 32], pub token_provenance: Vec<SemanticTokenProvenance>, pub cache: Vec<SemanticPublicationTensorProjection>,
}
Read-only original inputs projected through the complete publication codec. These content records are not proof of historical execution or use authority.

Fields

publication: SemanticPublishedIdentitysemantic_root: Identity256model_generation: u64model_geometry_digest: Identity256model_numerical_digest: Identity256neural_generation: u64cache_generation: u64prefix_extent: u64ring_head: u64prefix_identity: Identity256prefix: Vec<SemanticTextSlot>source: [SemanticTextSlot; 32]token_provenance: Vec<SemanticTokenProvenance>cache: Vec<SemanticPublicationTensorProjection>