pub struct SemanticTaskObjectiveLaw {
pub return_bound: i64,
pub evaluator_min: f64,
pub evaluator_max: f64,
pub coefficients: [f32; 9],
pub structural_cost: SemanticStructuralCostDescriptor,
}Expand description
Evaluator interval and objective coefficients frozen by the native task before actions, independently of any future training-group membership.
Fields
return_bound: i64evaluator_min: f64evaluator_max: f64coefficients: [f32; 9]structural_cost: SemanticStructuralCostDescriptorTrait Implementations
Sourceimpl Clone for SemanticTaskObjectiveLaw
impl Clone for SemanticTaskObjectiveLaw
Sourcefn clone(&self) -> SemanticTaskObjectiveLaw
fn clone(&self) -> SemanticTaskObjectiveLaw
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SemanticTaskObjectiveLaw
Sourceimpl Debug for SemanticTaskObjectiveLaw
impl Debug for SemanticTaskObjectiveLaw
Sourceimpl PartialEq for SemanticTaskObjectiveLaw
impl PartialEq for SemanticTaskObjectiveLaw
impl StructuralPartialEq for SemanticTaskObjectiveLaw