pub struct SemanticTrainingManifest {
pub identity: Identity256,
pub caps: [u64; 4],
}Expand description
Exact sealed input identity and its four admission caps, in source order: entries, total keys, records per input, bytes per record.
Fields
identity: Identity256caps: [u64; 4]Trait Implementations
Sourceimpl Clone for SemanticTrainingManifest
impl Clone for SemanticTrainingManifest
Sourcefn clone(&self) -> SemanticTrainingManifest
fn clone(&self) -> SemanticTrainingManifest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SemanticTrainingManifest
impl Debug for SemanticTrainingManifest
impl Eq for SemanticTrainingManifest
Sourceimpl PartialEq for SemanticTrainingManifest
impl PartialEq for SemanticTrainingManifest
impl StructuralPartialEq for SemanticTrainingManifest