#[repr(C)]pub struct SemanticTrainingRosterRow {
pub ordinal: u64,
pub basis: u64,
pub window: u64,
pub source_length: u64,
pub block_size: u64,
pub prefix_extent: u64,
pub answer_start: u64,
pub origin_candidate: u64,
pub identity: [u64; 4],
pub source_identity: [u64; 4],
pub content_identity: [u64; 4],
pub origin: SemanticTrainingViewOriginRecord,
}Expand description
Device-written metadata for every row in the selected objective roster.
Fields
ordinal: u64basis: u64window: u64source_length: u64block_size: u64prefix_extent: u64answer_start: u64origin_candidate: u64identity: [u64; 4]source_identity: [u64; 4]content_identity: [u64; 4]origin: SemanticTrainingViewOriginRecordAuthenticated historical execution origin for episode rows. The separate candidate ordinal, when present, names a successful fresh re-execution.