pub struct SemanticTrainingViewOrigin {
pub transition: SemanticTransitionKind,
pub predecessor: SemanticPublishedIdentity,
pub successor: SemanticPublishedIdentity,
pub invocation: SemanticRngBinding,
pub model_geometry_digest: Identity256,
pub model_numerical_digest: Identity256,
}Expand description
Authenticated native execution that produced one episode training view. Corpus anchors have no execution origin and use their independent graph.
Fields
transition: SemanticTransitionKindpredecessor: SemanticPublishedIdentitysuccessor: SemanticPublishedIdentityinvocation: SemanticRngBindingmodel_geometry_digest: Identity256model_numerical_digest: Identity256Trait Implementations
Sourceimpl Clone for SemanticTrainingViewOrigin
impl Clone for SemanticTrainingViewOrigin
Sourcefn clone(&self) -> SemanticTrainingViewOrigin
fn clone(&self) -> SemanticTrainingViewOrigin
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SemanticTrainingViewOrigin
Sourceimpl Debug for SemanticTrainingViewOrigin
impl Debug for SemanticTrainingViewOrigin
impl Eq for SemanticTrainingViewOrigin
impl StructuralPartialEq for SemanticTrainingViewOrigin