pub struct RootMetadata {
pub column_permutation: Vec<u8>,
pub sorted_layout_signature: LayoutSignature,
pub heat_distribution: HeatDist,
}Expand description
Metadata cached for one candidate root variable.
Fields
column_permutation: Vec<u8>Column permutation needed to expose this root as the leading key.
sorted_layout_signature: LayoutSignatureSignature of the sorted layout used by this candidate root.
heat_distribution: HeatDistHeavy-key heat distribution for this root.