#[repr(C)]pub struct ResidentOpDescriptor {Show 18 fields
pub kind: ResidentScheduleOpKind,
pub flags: u32,
pub op_id: u32,
pub out: u32,
pub in0: u32,
pub in1: u32,
pub in0_generation: u32,
pub in1_generation: u32,
pub out_generation: u32,
pub aux_offset: u32,
pub aux_count: u32,
pub left_key: u32,
pub right_key: u32,
pub scan_delta: u32,
pub filter_delta: u32,
pub schema_winner_head: u32,
pub schema_winner_id: u32,
pub reserved: u32,
}Expand description
One operation in stable schedule order.
Fields
kind: ResidentScheduleOpKindflags: u32op_id: u32out: u32in0: u32in1: u32in0_generation: u32in1_generation: u32out_generation: u32aux_offset: u32aux_count: u32left_key: u32right_key: u32scan_delta: u32filter_delta: u32schema_winner_head: u32schema_winner_id: u32reserved: u32Implementations
Sourceimpl ResidentOpDescriptor
impl ResidentOpDescriptor
Sourcepub fn unit(op_id: u32, out: u32, out_generation: u32) -> Self
pub fn unit(op_id: u32, out: u32, out_generation: u32) -> Self
Construct a nullary Unit leaf that writes one logical empty tuple.
Sourcepub fn scan(op_id: u32, source: u32, source_generation: u32) -> Self
pub fn scan(op_id: u32, source: u32, source_generation: u32) -> Self
Construct a Scan leaf that binds an existing immutable source slot.
pub fn with_schema_winner(self, head: u32, schema_id: u32) -> Self
pub fn test_status(status: ResidentTerminalStatus) -> Result<Self>
pub fn trace_delta( scan_delta: u32, filter_delta: u32, semantic_guard: Option<(u32, u32)>, ) -> Self